########
Examples
########

The following examples will guide you through the functionality of *aristopy*.
The first example shows a straightforward application to introduce you to the
basic model setup and the notation of *aristopy*.
More advanced features are presented with a larger model in the second example.
The last example model shows some functionality that is helpful when working
with models that utilize solar components (solar thermal collectors or
photovoltaic modules).

.. toctree::
   :maxdepth: 1

   model_to_get_started
   advanced_features
   solar_components